@@ -10,11 +10,11 @@ Acme::KENO - The great new Acme::KENO!
 
 =head1 VERSION
 
-Version 0.02_02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -26,7 +26,6 @@ Perhaps a little code snippet.
     use Acme::KENO;
 
     my $foo = Acme::KENO->new();
-    $foo->iterator( $coderef );
     ...
 
 =head1 EXPORT
@@ -34,33 +33,25 @@ Perhaps a little code snippet.
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-=head1 METHODS
+=head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 function1
 
 =cut
 
-sub new { bless {} => ref( $_[0] ) || $_[0] }
+sub function1 {
+}
 
-=head2 iterator
+=head2 function2
 
 =cut
 
-sub iterator { $_[0]->{iterator} }
-
-=head2 set_iterator
-
-=cut
-
-sub set_iterator {
-    my( $self, $iterator ) = @_;
-    $self->{iterator} = $iterator;
-    return $self;
+sub function2 {
 }
 
 =head1 AUTHOR
 
-Ken Olstad, C<< <keno at cpan.org> >>
+keno, C<< <keno at cpan.org> >>
 
 =head1 BUGS
 
@@ -68,6 +59,9 @@ Please report any bugs or feature requests to C<bug-acme-keno at rt.cpan.org>, o
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-KENO>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
